"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const color_1 = __importDefault(require("color"));
function toHexString(color) {
    return color instanceof color_1.default ? color.hex() : color;
}
function toColorObj(color) {
    return color instanceof color_1.default ? color : new color_1.default(color);
}
class ColorCollection {
    constructor() {
        this._named = new Map();
        this._anonymous = new Set();
    }
    _containsNamedColorValue(color) {
        const searchColor = toHexString(color);
        let found = false;
        for (const existingColor of this._named.values()) {
            if (existingColor === searchColor) {
                found = true;
                break;
            }
        }
        return found;
    }
    _containsAnonymousColorValue(color) {
        return this._anonymous.has(toHexString(color));
    }
    containsColorValue(color) {
        return this._containsAnonymousColorValue(color) || this._containsNamedColorValue(color);
    }
    addColor(color, name) {
        const hexColor = toHexString(color);
        if (name === undefined) {
            if (!this._containsNamedColorValue(color)) {
                this._anonymous.add(hexColor);
            }
        }
        else {
            if (this._containsAnonymousColorValue(color)) {
                this._anonymous.delete(hexColor);
            }
            this._named.set(name, hexColor);
        }
    }
    getNamedColors() {
        return [...this._named].reduce((namedColors, [name, colorVal]) => {
            namedColors[name] = new color_1.default(colorVal);
            return namedColors;
        }, {});
    }
    getNamedSize() {
        return this._named.size;
    }
    getAnonymousColors() {
        return [...this._anonymous].map(toColorObj);
    }
    getAnonymousSize() {
        return this._anonymous.size;
    }
    get size() {
        return this.getAnonymousSize() + this.getNamedSize();
    }
}
exports.default = ColorCollection;
//# sourceMappingURL=color-collection.js.map