"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, privateMap, value) {
    if (!privateMap.has(receiver)) {
        throw new TypeError("attempted to set private field on non-instance");
    }
    privateMap.set(receiver, value);
    return value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, privateMap) {
    if (!privateMap.has(receiver)) {
        throw new TypeError("attempted to get private field on non-instance");
    }
    return privateMap.get(receiver);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _plugins, _config;
Object.defineProperty(exports, "__esModule", { value: true });
const color_collection_1 = __importDefault(require("./color-collection"));
const plugin_manager_1 = __importDefault(require("./plugin-manager"));
class ColorGlue {
    constructor(plugins, config) {
        _plugins.set(this, new plugin_manager_1.default());
        _config.set(this, void 0);
        plugins.forEach(plugin => {
            this.registerPlugin(plugin);
        });
        __classPrivateFieldSet(this, _config, config);
    }
    appendImporterConfig(config) {
        __classPrivateFieldGet(this, _config).importers.push(config);
    }
    appendUrlGeneratorConfig(config) {
        __classPrivateFieldGet(this, _config).urlGenerators.push(config);
    }
    async importColors() {
        let colors = new color_collection_1.default();
        for (const importerPluginConfig of __classPrivateFieldGet(this, _config).importers) {
            const key = typeof importerPluginConfig === 'string' ? importerPluginConfig : importerPluginConfig.name;
            const config = importerPluginConfig.importConfig;
            const plugin = __classPrivateFieldGet(this, _plugins).getImporterPlugin(key);
            if (plugin === undefined) {
                console.warn(`Could not find importer plugin with key: ${key}`);
                continue;
            }
            colors = await plugin.import(colors, config);
        }
        return colors;
    }
    async generateUrls(colors) {
        const urls = [];
        for (const urlGenPluginConfig of __classPrivateFieldGet(this, _config).urlGenerators) {
            const key = typeof urlGenPluginConfig === 'string' ? urlGenPluginConfig : urlGenPluginConfig.name;
            const config = urlGenPluginConfig.urlGeneratorConfig;
            const plugin = __classPrivateFieldGet(this, _plugins).getUrlGeneratorPlugin(key);
            if (plugin === undefined) {
                console.warn(`Could not find URL generator plugin with key: ${key}`);
                continue;
            }
            urls.push(await plugin.generateUrl(colors, config));
        }
        return urls;
    }
    async run() {
        const colors = await this.importColors();
        const urls = await this.generateUrls(colors);
        return {
            colors,
            urls,
        };
    }
    registerPlugin(plugin) {
        __classPrivateFieldGet(this, _plugins).registerPlugin(plugin);
    }
    getPluginsInfo() {
        return __classPrivateFieldGet(this, _plugins).getPluginsInfo();
    }
}
exports.default = ColorGlue;
_plugins = new WeakMap(), _config = new WeakMap();
//# sourceMappingURL=color-glue.js.map