"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const https_1 = __importDefault(require("https"));
const configKey = 'invisionDsm';
function isColorCollection(tokenOrCollection) {
    return tokenOrCollection.colors !== undefined && Array.isArray(tokenOrCollection.colors);
}
class DsmPlugin {
    get configKey() {
        return configKey;
    }
    get displayName() {
        return 'InVision DSM';
    }
    async import(colors, config) {
        const urls = Array.isArray(config.url) ? config.url : [config.url];
        for (const url of urls) {
            const jsonString = await new Promise((resolve, reject) => {
                https_1.default.get(url, res => {
                    let responseBody = '';
                    res.on('data', chunk => {
                        responseBody += chunk;
                    });
                    res.on('end', () => {
                        resolve(responseBody);
                    });
                }).on('error', reject);
            });
            const designTokenData = JSON.parse(jsonString);
            if (designTokenData.list !== undefined) {
                designTokenData.list.colors.forEach(colorCategory => {
                    colorCategory.colors.forEach(colorToken => {
                        colors.addColor(colorToken.value, colorToken.name);
                    });
                });
            }
            if (designTokenData.lookup !== undefined) {
                Object.getOwnPropertyNames(designTokenData.lookup.colors).forEach(colorOrCategoryName => {
                    const colorOrCategory = designTokenData.lookup.colors[colorOrCategoryName];
                    if (isColorCollection(colorOrCategory)) {
                        colorOrCategory.colors.forEach(colorToken => {
                            colors.addColor(colorToken.value, colorToken.name);
                        });
                    }
                    else {
                        colors.addColor(colorOrCategory.value, colorOrCategory.name);
                    }
                });
            }
        }
        return colors;
    }
}
exports.default = DsmPlugin;
//# sourceMappingURL=invision-dsm.js.map